@@ -431,24 +431,22 @@ GEN
 lfundiv(GEN ldata1, GEN ldata2, long bitprec)
 {
   pari_sp ltop = avma;
-  GEN k, r, N, v, eno, a1a2, b1b2, LD, eno2;
+  GEN k, r, N, v, eno, a1a2, b1b2, eno2;
   long prec = nbits2prec(bitprec);
   ldata1 = ldata_newprec(lfunmisc_to_ldata_shallow(ldata1), prec);
   ldata2 = ldata_newprec(lfunmisc_to_ldata_shallow(ldata2), prec);
   k = ldata_get_k(ldata1);
   if (!gequal(ldata_get_k(ldata2),k))
     pari_err_OP("lfundiv [weight]",ldata1, ldata2);
-  r = lfundivpoles(ldata1, ldata2, bitprec);
   N = gdiv(ldata_get_conductor(ldata1), ldata_get_conductor(ldata2));
   if (typ(N) != t_INT) pari_err_OP("lfundiv [conductor]",ldata1, ldata2);
+  r = lfundivpoles(ldata1, ldata2, bitprec);
   a1a2 = lfunconvolinv(ldata_get_an(ldata1), ldata_get_an(ldata2));
   b1b2 = lfuncombdual(lfunconvolinv, ldata1, ldata2);
   eno2 = ldata_get_rootno(ldata2);
   eno = isintzero(eno2)? gen_0: gdiv(ldata_get_rootno(ldata1), eno2);
   v = lfunvgasub(ldata_get_gammavec(ldata1), ldata_get_gammavec(ldata2));
-  LD = mkvecn(7, a1a2, b1b2, v, k, N, eno, r);
-  if (!r) setlg(LD,7);
-  return gerepilecopy(ltop, LD);
+  return gerepilecopy(ltop,  mkvecn(r? 7: 6, a1a2, b1b2, v, k, N, eno, r));
 }
 
 static GEN
@@ -1108,9 +1106,9 @@ lfunchigen(GEN bnr, GEN CHI)
   if (typ(CHI) == t_VEC && !RgV_is_ZV(CHI))
   {
     long map, i, l = lg(CHI);
-    GEN bnr0, D, chi = gel(CHI,1), o = gen_1;
+    GEN bnr0 = bnr, D, chi = gel(CHI,1), o = gen_1;
     nchi = cgetg(l, t_VEC);
-    bnr_char_sanitize(&bnr, &chi); bnr0 = bnr;
+    bnr_char_sanitize(&bnr, &chi);
     D = cyc_normalize(bnr_get_cyc(bnr));
     N = bnr_get_mod(bnr);
     map = (bnr != bnr0);
